@@ -1,4 +1,4 @@
-# $Id: MeGa.pm 172 2008-11-12 12:25:41Z fish $
+# $Id: MeGa.pm 180 2008-11-15 14:08:56Z fish $
 package WWW::MeGa;
 use 5.6.0;
 use strict;
@@ -17,12 +17,14 @@ WWW::MeGa - A MediaGallery
 =head1 DESCRIPTION
 
 WWW::MeGa is a web based media gallery. It should
-be run from mod_perl or FastCGI (see examples/gallery.fcgi) because
-it uses some runtime caching.
+be run from FastCGI (see examples/gallery.fcgi) or mod_perl (not yet
+tested) because it uses some runtime caching.
 
 Every file will be delievered by the CGI itself. So you don't have
 to care about setting up picture/thumb dirs.
 
+To see it in action, visit: http://freigeist.org/gallery
+or http://sophiesfotos.de
 
 =head1 FEATURES
 
@@ -36,13 +38,98 @@ to care about setting up picture/thumb dirs.
 
 =item * reads exif tag
 
+=item * very easy to setup (change one path in the config and your done)
+
 =item * templating with L<HTML::Template::Compiled>
 
 =back
 
 =head1 INSTALLATION
 
-TBD
+=head2 Install the package
+
+Use your favorite way to install this CPAN-Package and make sure you
+have C<ffmpeg> somewhere in your path (or specify the path in the
+config) if you want video thumbnails.
+
+If you want to install it via the cpan-installer use:
+
+ cpan WWW::MeGa
+
+To install a developer release of WWW::MeGa, use the CPAN-Shell:
+
+ perl -MCPAN -eshell
+
+Now you can see all releases with C<ls fish> and install the one you want: C<install FISH/WWW-MeGa-0.09_5.tar.gz>
+
+B<WARNING>: Installation via C<cpan> or the CPAN-Shell is only recommended
+if you have a local administered perl installation.  If you installed
+perl from your packet manager you should use the packet manager to
+install this package too. Have a look at C<g-cpan> (Gentoo) and
+C<dh-make-perl> (Debian/Ubuntu).
+
+
+=head3 Use FastCGI (preferred) 
+
+Copy C<examples/gallery.fcgi> to some dir and configure your webserver to
+use it as a FastCGI:
+
+Example for lighttpd:
+
+   fastcgi.server = (
+                        "/gallery" =>
+                        ( "localhost" =>
+                                (
+                                        "socket"        => "/var/run/lighttpd/gallery" + PID + ".socket",
+                                        "check-local"   => "disable",
+                                        "bin-path"      => "/var/www/gallery.fcgi"
+                                )
+                        ),
+   )
+
+=head3 Use CGI
+
+Copy C<examples/gallery.cgi> to your C<cgi-bin/> directory and make
+sure its executable. Now WWW::MeGa should have created a default config
+file. Change 'root' to your images and you are done.
+
+=head3 Config
+
+Make sure the user under which the webserver is running has write
+permission to the config file. The path to the config file defaults to
+to 'gallery.conf' in the same dir as your script. In these cases:
+C</var/www/gallery.conf> (FCGI) and
+C</path/to/your/cgi-bin/gallery.conf>.
+
+You can (and should, at least in the CGI case) specify a custom path to
+the config by changing the scripts to pass:
+
+ PARAMS => { config => '/path/to/your/config' }
+
+to the new method of L<WWW::MeGa>.
+
+=head4 modified gallery.fcgi
+
+ ...
+ my $app = WWW::MeGa->new
+ (
+         QUERY => $q,
+         PARAMS => { cache => \%cache, config => '/path/to/your/config' },
+ );
+ ...
+
+=head4 modified gallery.cgi
+
+ ...
+ my $webapp = WWW::MeGa->new(PARAMS => {config => '/path/to/your/config'});
+ ...
+
+=head2 Test it
+
+Now visit the the URL to you script. (In these examples:
+http://example.com/gallery (FastCGI) and
+http://example.com/cgi-bin/gallery.cgi (CGI)) and you
+should see the example photos. 
 
 =head1 CONFIG
 
@@ -73,6 +160,22 @@ L<WWW::MeGa> uses L<Image::Magick> for generating thumbnails.
 See C<convert -list format> for file types supported by you ImageMagick
 installation.
 
+=head3 video-thumbs
+
+If set to 1, enables video-thumbs. Default: 1
+
+=head3 video-thumbs-offset
+
+specifies which frame to grab in seconds. Default: 10
+
+=head3 exif
+
+If set to 1, enables the extraction of exif-data. Default: 1
+
+=head3 ffmpeg-path
+
+Specify the path to the ffmpeg-binary. Defaults to 'ffmpeg'. (Should be
+looked up in your PATH)
 
 =head3 sizes
 
@@ -118,7 +221,7 @@ use WWW::MeGa::Item;
 
 use Carp;
 
-our $VERSION = '0.09_4';
+our $VERSION = '0.09_5';
 sub setup
 {
 	my $self = shift;
@@ -134,6 +237,10 @@ sub setup
 		'cache' => '/tmp/www-mega',
 		'album_thumb' => 'THUMBNAIL',
 		'thumb-type' => 'png',
+		'video-thumbs' => 1,
+		'video-thumbs-offset' => 10,
+		'exif' => 1,
+		'ffmpeg-path' => 'ffmpeg',
 		'root' => File::Spec->catdir($share, 'images'),
 		'debug' => 0,
 		'icons' => File::Spec->catdir($share, 'icons'),
@@ -263,9 +370,9 @@ sub view_original
 }
 
 
-=head3 view
+=head3 view (DEFAULT RUNMODE)
 
-shows a album/folder
+shows a html page with one or more items
 
 =cut
 
@@ -339,12 +446,48 @@ sub binary
 	}
 }
 
+=head1 BUGS, TODO AND NEW FEATURES
+
+I tried to write a clean and elegant app but I'm not a perl guru so
+B<please> bash me about everything you think suck in this project. I'm
+willing to learn and appreciate constructive critic.
+
+If you think this app is cool and you like to see new features please
+let me know!
+
+=head1 THANKS
+
+Thanks to EXP (at least I guess he was it) who suggests me to learn
+perl some years ago.
+
+And thanks alot to the people from irc.perl.org / #perlde for the
+current support.
+
 =head1 COPYRIGHT
 
+=head2 Code
+
 Copyright 2008 by Johannes 'fish' Ziemke.
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
+=head3 Icons
+
+The shipped icons are copyrighted by the "Tango Desktop Project" and
+are licensed under the Creative Commons Attribution Share-Alike 2.5
+license. See http://creativecommons.org/licenses/by-sa/2.5
+
+=head3 Photos
+
+biene.jpg and steine.jpg are copyrighted by Sophie Bischoff. For
+more, see: http://sophiesfotos.de
+
+moewe.jpg is copyrighted by Johannes 'fish' Ziemke.
+
+The shipped example photos are licensed unter the Creative Commons
+Attribution Share-Alike 3.0 license. See
+http://creativecommons.org/licenses/by-sa/3.0/
 
 =head1 SEE ALSO
 
